.. This README is meant for consumption by humans and pypi. Pypi can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide.html
   This text does not appear on pypi or github. It is a comment.

.. image:: https://travis-ci.org/collective/collective.imagemaps.svg?branch=master
    :target: https://travis-ci.org/collective/collective.imagemaps

.. image:: https://coveralls.io/repos/github/collective/collective.imagemaps/badge.svg?branch=master
    :target: https://coveralls.io/github/collective/collective.imagemaps?branch=master
    :alt: Coveralls

.. image:: https://img.shields.io/pypi/v/collective.imagemaps.svg
    :target: https://pypi.python.org/pypi/collective.imagemaps/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/status/collective.imagemaps.svg
    :target: https://pypi.python.org/pypi/collective.imagemaps
    :alt: Egg Status

.. image:: https://img.shields.io/pypi/pyversions/collective.imagemaps.svg?style=plastic   :alt: Supported - Python Versions

.. image:: https://img.shields.io/pypi/l/collective.imagemaps.svg
    :target: https://pypi.python.org/pypi/collective.imagemaps/
    :alt: License


====================
collective.imagemaps
====================

Provides an Image Map Behavior for Documents in Plone.
The Image Map markup is inserted via ImageMapViewlet below the content body.


Installation
------------

Install collective.imagemaps by adding it to your buildout::

    [buildout]

    ...

    eggs =
        collective.imagemaps


and then running ``bin/buildout``


Contribute
----------

- Issue Tracker: https://github.com/collective/collective.imagemaps/issues
- Source Code: https://github.com/collective/collective.imagemaps


Support
-------

If you are having issues, please open an issue in the tracker.


License
-------

The project is licensed under the GPLv2.
